==> grond-1.5.0.tar.gz: grond-1.5.0/README.md <==
# Grond

A probabilistic earthquake source inversion framework

Grond is an open source software tool for robust characterization of earthquake sources. Moment tensors and finite fault rupture models can be estimated from seismic, InSAR, and GNSS observations. It serves as a modular framework for the analysis of diverse tectonic, magmatic, and other geophysical processes at all scales. [Read on...](https://pyrocko.org/grond/)

## Documentation and installation

Find the documentation and install instructions at https://pyrocko.org/grond/.

## Community and support

Please use the [Grond channel](https://hive.pyrocko.org/pyrocko-support/channels/grond) in the [Pyrocko Hive](https://hive.pyrocko.org) for discussion and feedback. To file a bug report, please use [Issues](https://git.pyrocko.org/pyrocko/grond/issues).

## Citation

The recommended citation for Grond is:

>  Heimann, Sebastian; Isken, Marius; Kühn, Daniela; Sudhaus, Henriette; Steinberg, Andreas; Vasyura-Bathke, Hannes; Daout, Simon; Cesca, Simone; Dahm, Torsten (2018): Grond - A probabilistic earthquake source inversion framework. V. 1.0. GFZ Data Services.

[![DOI](https://img.shields.io/badge/DOI-10.5880%2FGFZ.2.1.2018.003-blue.svg)](https://doi.org/10.5880/GFZ.2.1.2018.003)

You can find the BibTeX snippet in the [`CITATION` file](CITATION.bib).

## License

GNU General Public License, Version 3, 29 June 2007

Copyright © 2018 Helmholtz Centre Potsdam GFZ German Research Centre for
Geosciences, Potsdam, Germany and University of Kiel, Kiel, Germany.

Grond is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version. Grond is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.

## Contact
* Sebastian Heimann - sebastian.heimann@gfz-potsdam.de
* Marius Isken - marius.isken@gfz-potsdam.de

```
Helmholtz Centre Potsdam German Research Centre for Geoscienes GFZ
Section 2.1: Physics of Earthquakes and Volcanoes
Helmholtzstraße 6/7
14467 Potsdam, Germany
```

==> grond-1.6.0.tar.gz: grond-1.6.0/README.md <==
# Grond

A probabilistic earthquake source inversion framework

Grond is an open source software tool for robust characterization of earthquake sources. Moment tensors and finite fault rupture models can be estimated from seismic, InSAR, and GNSS observations. It serves as a modular framework for the analysis of diverse tectonic, magmatic, and other geophysical processes at all scales. [Read on...](https://pyrocko.org/grond/)

## Documentation and installation

Find the documentation and detailed install instructions at https://pyrocko.org/grond/.

## Community and support

Please use the [Grond channel](https://hive.pyrocko.org/pyrocko-support/channels/grond) in the [Pyrocko Hive](https://hive.pyrocko.org) for discussion and feedback. To file a bug report, please use [Issues](https://git.pyrocko.org/pyrocko/grond/issues).

## Citation

The recommended citation for Grond is:

>  Heimann, Sebastian; Isken, Marius; Kühn, Daniela; Sudhaus, Henriette; Steinberg, Andreas; Vasyura-Bathke, Hannes; Daout, Simon; Cesca, Simone; Dahm, Torsten (2018): Grond - A probabilistic earthquake source inversion framework. V. 1.0. GFZ Data Services.

[![DOI](https://img.shields.io/badge/DOI-10.5880%2FGFZ.2.1.2018.003-blue.svg)](https://doi.org/10.5880/GFZ.2.1.2018.003)

You can find the BibTeX snippet in the [`CITATION` file](CITATION.bib).

## License

GNU General Public License, Version 3, 29 June 2007

Copyright © 2018 Helmholtz Centre Potsdam GFZ German Research Centre for
Geosciences, Potsdam, Germany and University of Kiel, Kiel, Germany.

Grond is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version. Grond is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.

## Contact
* Sebastian Heimann - sebastian.heimann@gfz-potsdam.de
* Marius Isken - marius.isken@gfz-potsdam.de

```
Helmholtz Centre Potsdam German Research Centre for Geoscienes GFZ
Section 2.1: Physics of Earthquakes and Volcanoes
Helmholtzstraße 6/7
14467 Potsdam, Germany
```
